import  {useState, useEffect } from 'react'
import { OrderService } from 'services'
import { Order } from 'Order'

enum ResStatus {
    IDLE = "IDLE",
    FETCHING = "FETCHING",
    SUCCESS = "SUCCESS",
    ERROR = "ERROR"
}

const useAllOrders = () => {
    const [status, setStatus] = useState<ResStatus>(ResStatus.IDLE);
    const [data, setData] = useState<Order[]>([]);
    const [error, setError] = useState(null);

    useEffect(() => {
    
        const fetchOrders = async () => {
            setStatus(ResStatus.FETCHING);
            try {
                const ordersData = await OrderService.allOrders()
                setData(ordersData);
                setStatus(ResStatus.SUCCESS)
            } catch (err) {
                setError(err)
                setStatus(ResStatus.ERROR);
            }
        };

        fetchOrders();
    }, []);

    return { status, data, orders: data, error, ResStatus };
};

export default useAllOrders;